@@ -17,10 +17,11 @@ KEY__uninstall_key = "uninstall_key"
 KEY__install_key = "install_key"
 KEY__deletion_key = "deletion_key"
 KEY__render_as = "render_as"
-KEY__default_tenant_password = "default_tenant_password"
+KEY__default_password = "default_password"
 KEY__url = "url"
 KEY__artifact_base_uri = "artifact_base_uri"
-KEY__superjaaql_password = "superjaaql_password"
+KEY__jaaql_password = "jaaql_password"
+KEY__super_db_password = "super_db_password"
 KEY__public_username = "public_username"
 KEY__records_total = "records_total"
 KEY__records_filtered = "records_filtered"
@@ -94,8 +95,7 @@ KEY__use_mfa = "use_mfa"
 KEY__show_deleted = "show_deleted"
 KEY__description = "description"
 KEY__the_role = "the_role"
-KEY__tenant_admin_password = "tenant_admin_password"
-KEY__the_tenant = "the_tenant"
+KEY__admin_password = "admin_password"
 KEY__database_name = "name"
 KEY__create = "create"
 KEY__drop = "drop"
@@ -105,14 +105,13 @@ KEY__old_password = "old_password"
 KEY__address = "address"
 KEY__public_password = "public_password"
 KEY__jaaql_name = "jaaql_name"
-KEY__tenant_name = "name"
 KEY__level = "level"
 KEY__code = "code"
 KEY__access_rank = "access_rank"
 KEY__otp_uri = "otp_uri"
 KEY__otp_qr = "otp_qr"
-KEY__default_tenant_otp_uri = "default_tenant_otp_uri"
-KEY__default_tenant_otp_qr = "default_tenant_otp_qr"
+KEY__default_otp_uri = "default_otp_uri"
+KEY__default_otp_qr = "default_otp_qr"
 KEY__superjaaql_otp_uri = "superjaaql_otp_uri"
 KEY__superjaaql_otp_qr = "superjaaql_otp_qr"
 KEY__is_public = "is_public"
@@ -135,7 +134,6 @@ KEY__allow_signup = "allow_signup"
 KEY__email_account_name = "name"
 KEY__email_sent = "sent"
 KEY__password_hash = "password_hash"
-KEY__tenant = "tenant"
 KEY__user_id = "user_id"
 KEY__body = "body"
 KEY__default_email_signup_template = "default_email_signup_template"
@@ -244,7 +242,7 @@ HTML__base64_png = "data:image/png;base64,"
 FORMAT__png = "png"
 
 NODE__host_node = "host"
-DB__jaaql = "jaaql__jaaql"
+DB__jaaql = "jaaql"
 DB__postgres = "postgres"
 
 PORT__ems = 6061
@@ -268,12 +266,11 @@ DATASET__default_desc = "Default dataset description"
 HTTP_STATUS__too_early = 425  # Shiv for python 3.8
 
 USERNAME__jaaql = "jaaql"
-USERNAME__superjaaql = "superjaaql"
-USERNAME__super = "super"
+USERNAME__super_db = "super_db"
 ROLE__jaaql = "jaaql"
 ROLE__postgres = "postgres"
 
 PROTOCOL__postgres = "postgresql://"
 
-VERSION = "4.1.9"
+VERSION = "4.3.0"
 
