@@ -7,7 +7,9 @@ from jaaql.db.db_interface import DBInterface
 from jaaql.db.db_utils import execute_supplied_statement, execute_supplied_statement_singleton
 from jaaql.exceptions.http_status_exception import HttpStatusException
 from jaaql.utilities.utils import load_config, await_jaaql_installation, get_jaaql_connection, time_delta_ms
+from jaaql.utilities.crypt_utils import decrypt_raw
 from urllib.parse import quote
+from jaaql.utilities.utils_no_project_imports import check_allowable_file_path
 import json
 import imaplib
 import smtplib
@@ -26,21 +28,22 @@ import sys
 from flask import Flask, jsonify, request
 from jaaql.utilities.vault import Vault, DIR__vault
 from jaaql.constants import VAULT_KEY__db_crypt_key, KEY__encrypted_password, KEY__id, KEY__template, KEY__sender, ENCODING__ascii, PORT__ems, \
-    ENDPOINT__reload_accounts, ENDPOINT__send_email, KEY__email_account_name, KEY__attachment_name, KEY__parameters, KEY__url, KEY__oauth_token, \
+    ENDPOINT__reload_accounts, ENDPOINT__send_email, KEY__attachment_name, KEY__parameters, KEY__url, KEY__oauth_token, \
     KEY__document_id, KEY__create_file, DIR__render_template, KEY__render_as, KEY__content, DIR__www, KEY__email_account_name, \
-    KEY__email_account_send_name, KEY__email_account_protocol, KEY__email_account_host, KEY__email_account_port, KEY__email_account_username
+    KEY__email_account_send_name, KEY__email_account_protocol, KEY__email_account_host, KEY__email_account_port, KEY__email_account_username, \
+    KEY__override_send_name, KEY__application, ENVIRON__install_path, KEY__artifact_base_uri
 
 from selenium import webdriver
 from selenium.webdriver.common.by import By
 from selenium.webdriver.chrome.options import Options
 
-QUERY__mark_rendered_document_completed = "UPDATE jaaql__rendered_document SET completed = current_timestamp, filename = :filename, content = :content WHERE document_id = :document_id"
-QUERY__fetch_unrendered_document = "SELECT able.url, able.render_as, rd.document_id, rd.encrypted_parameters as parameters, rd.create_file, rd.encrypted_access_token as oauth_token FROM jaaql__rendered_document rd INNER JOIN jaaql__renderable_document able ON rd.document = able.name WHERE rd.completed is null ORDER BY rd.created LIMIT 1"
-QUERY__update_email_account_password = "UPDATE jaaql__email_account SET encrypted_password = :encrypted_password WHERE id = :id"
-QUERY__load_email_accounts = "SELECT * FROM jaaql__email_account WHERE deleted is null"
-QUERY__ins_email_history = "INSERT INTO jaaql__email_history (template, sender, encrypted_subject, encrypted_body, encrypted_attachments, encrypted_recipients, encrypted_recipients_keys) VALUES (:template, :sender, :encrypted_subject, :encrypted_body, :encrypted_attachments, :encrypted_recipients, :encrypted_recipients_keys)"
-QUERY__fetch_email_template = "SELECT rd.url FROM jaaql__renderable_document rd INNER JOIN jaaql__renderable_document_template rdt ON rd.name = rdt.attachment WHERE rd.name = :name AND rdt.template = :template"
-QUERY__purge_rendered_documents = "DELETE FROM jaaql__rendered_document rd USING jaaql__renderable_document able WHERE rd.document = able.name AND completed is not null and completed > current_timestamp + interval '5 minutes' RETURNING rd.document_id, rd.create_file, able.render_as"
+QUERY__mark_rendered_document_completed = "UPDATE rendered_document SET completed = current_timestamp, filename = :filename, content = :content WHERE document_id = :document_id"
+QUERY__fetch_unrendered_document = "SELECT able.url, ac.artifact_base_uri, able.render_as, rd.document_id, rd.encrypted_parameters as parameters, rd.create_file, rd.encrypted_access_token as oauth_token FROM rendered_document rd INNER JOIN renderable_document able ON rd.document = able.name INNER JOIN application_configuration ac ON rd.configuration = ac.name AND rd.application = ac.application WHERE rd.completed is null ORDER BY rd.created LIMIT 1"
+QUERY__update_email_account_password = "UPDATE email_account SET encrypted_password = :encrypted_password WHERE id = :id"
+QUERY__load_email_accounts = "SELECT * FROM email_account"
+QUERY__ins_email_history = "INSERT INTO email_history (application, template, sender, encrypted_subject, encrypted_body, encrypted_attachments, encrypted_recipients, encrypted_recipients_keys, override_send_name) VALUES (:application, :template, :sender, :encrypted_subject, :encrypted_body, :encrypted_attachments, :encrypted_recipients, :encrypted_recipients_keys, :override_send_name)"
+QUERY__fetch_email_template = "SELECT rd.url FROM renderable_document rd INNER JOIN renderable_document_template rdt ON rd.name = rdt.attachment WHERE rd.name = :name AND rdt.template = :template"
+QUERY__purge_rendered_documents = "DELETE FROM rendered_document rd USING renderable_document able WHERE rd.document = able.name AND completed is not null and completed > current_timestamp + interval '5 minutes' RETURNING rd.document_id, rd.create_file, able.render_as"
 
 KEY__email_account = "email_account"
 KEY__encrypted_subject = "encrypted_subject"
@@ -48,6 +51,7 @@ KEY__encrypted_body = "encrypted_body"
 KEY__encrypted_attachments = "encrypted_attachments"
 KEY__encrypted_recipients = "encrypted_recipients"
 KEY__encrypted_recipients_keys = "encrypted_recipients_keys"
+KEY__artifact_base = "artifact_base"
 
 ATTR__filename = "filename"
 
@@ -139,7 +143,9 @@ class DrivenChrome:
                 parameters = {}
                 if resp[KEY__parameters]:
                     parameters = json.loads(resp[KEY__parameters])
-                filename, content = self.chrome_page_to_pdf(resp[KEY__url], resp[KEY__oauth_token], parameters)
+
+                base_uri = EmailAttachment.static_format_attached_url(resp[KEY__artifact_base_uri], self.is_deployed)
+                filename, content = self.chrome_page_to_pdf(base_uri, resp[KEY__oauth_token], parameters)
 
                 inputs = {KEY__document_id: resp[KEY__document_id], KEY__content: None, ATTR__filename: filename}
                 if resp[KEY__create_file]:
@@ -176,6 +182,9 @@ class DrivenChrome:
                     url = execute_supplied_statement_singleton(self.db_interface, QUERY__fetch_email_template,
                                                                {KEY__attachment_name: current_attachment.name,
                                                                 KEY__template: current_attachment.template}, as_objects=True)[KEY__url]
+                    if not url.endswith(".html"):
+                        url += ".html"
+                    url = current_attachment.artifact_base + "/" + url
                     filename, content = self.chrome_page_to_pdf(url, current_attachment.access_token, current_attachment.parameters)
                     current_attachment.content = content
                     current_attachment.filename = filename
@@ -190,8 +199,9 @@ class DrivenChrome:
 
 
 class EmailAttachment:
-    def __init__(self, name: str, parameters: dict, template: str):
+    def __init__(self, name: str, parameters: dict, template: str, artifact_base: str = None):
         self.name = name
+        self.artifact_base = artifact_base
         self.parameters = parameters
         self.id = str(uuid.uuid4())
         self.filename = None
@@ -199,6 +209,23 @@ class EmailAttachment:
         self.access_token = None
         self.template = str(template)
 
+    @staticmethod
+    def static_format_attached_url(artifact_base_uri: str, is_container: bool):
+        if not artifact_base_uri.startswith("https://") and not artifact_base_uri.startswith("http://"):
+            if is_container:
+                if check_allowable_file_path(artifact_base_uri):
+                    raise Exception("Illegal artifact base url")
+
+            if artifact_base_uri.startswith("file:///"):
+                return artifact_base_uri
+            else:
+                return "file://" + os.environ[ENVIRON__install_path] + "/www/" + artifact_base_uri
+        else:
+            return artifact_base_uri
+
+    def format_attachment_url(self, artifact_base_uri: str, is_container: bool):
+        self.artifact_base = EmailAttachment.static_format_attached_url(artifact_base_uri, is_container)
+
     def build_attachment(self, access_token: str, driven_chrome: DrivenChrome) -> MIMEApplication:
         self.access_token = access_token
         driven_chrome.attachments.put(self)
@@ -222,21 +249,22 @@ class EmailAttachment:
         return attachment
 
     def repr_json(self):
-        return dict(name=self.name, parameters=self.parameters, template=self.template)
+        return dict(name=self.name, parameters=self.parameters, template=self.template, artifact_base=self.artifact_base)
 
     @staticmethod
-    def deserialize(attachment: dict, template: str = None):
+    def deserialize(attachment: dict, template: str = None, artiface_base_url: str = None):
         if template is not None:
-            return EmailAttachment(attachment[KEY__attachment_name], attachment[KEY__parameters], template)
+            return EmailAttachment(attachment[KEY__attachment_name], attachment[KEY__parameters], template, artiface_base_url)
         else:
-            return EmailAttachment(attachment[KEY__attachment_name], attachment[KEY__parameters], attachment[KEY__template])
+            return EmailAttachment(attachment[KEY__attachment_name], attachment[KEY__parameters], attachment[KEY__template],
+                                   attachment[KEY__artifact_base])
 
     @staticmethod
-    def deserialize_list(attachments: list, template_id: str):
+    def deserialize_list(attachments: list, template: str, artiface_base_url: str):
         if attachments is None:
             return None
         else:
-            return [EmailAttachment.deserialize(attachment, template_id) for attachment in attachments]
+            return [EmailAttachment.deserialize(attachment, template, artiface_base_url) for attachment in attachments]
 
     def encode_filename(self):
         return b64e(self.filename.encode(ENCODING__ascii)).decode(ENCODING__ascii)
@@ -249,10 +277,11 @@ TYPE__email_attachments = Union[EmailAttachment, List[EmailAttachment]]
 
 
 class Email:
-    def __init__(self, sender: str, template: str, from_account: str, to: Union[str, List[str]], recipient_names: Union[str, List[str]],
-                 subject: str = None, body: str = None, attachments: TYPE__email_attachments = None, is_html: bool = True,
-                 attachment_access_token: str = None):
+    def __init__(self, sender: str, application: str, template: str, from_account: str, to: Union[str, List[str]],
+                 recipient_names: Union[str, List[str]], subject: str = None, body: str = None, attachments: TYPE__email_attachments = None,
+                 is_html: bool = True, attachment_access_token: str = None, override_send_name: str = None):
         self.sender = sender
+        self.application = application
         self.template = template
         self.from_account = from_account
         if isinstance(to, list) != isinstance(recipient_names, list):
@@ -268,24 +297,26 @@ class Email:
         self.subject = subject
         self.body = body
         self.attachments = attachments
+        self.override_send_name = override_send_name
         if not isinstance(self.attachments, List) and self.attachments is not None:
             self.attachments = [attachments]
         self.is_html = is_html
         self.attachment_access_token = attachment_access_token
 
     def repr_json(self):
-        return dict(sender=self.sender, template=self.template, from_account=self.from_account, to=self.to, recipient_names=self.recipient_names,
-                    subject=self.subject, body=self.body,
+        return dict(sender=self.sender, application=self.application, template=self.template, from_account=self.from_account,
+                    to=self.to, recipient_names=self.recipient_names, subject=self.subject, body=self.body,
                     attachments=[attachment.repr_json() for attachment in self.attachments] if self.attachments is not None else None,
-                    is_html=self.is_html, attachment_access_token=self.attachment_access_token)
+                    is_html=self.is_html, attachment_access_token=self.attachment_access_token, override_send_name=self.override_send_name)
 
     @staticmethod
     def deserialize(email: dict):
         attachments = None
         if email["attachments"] is not None:
             attachments = [EmailAttachment.deserialize(attachment) for attachment in email["attachments"]]
-        return Email(email["sender"], email["template"], email["from_account"], email["to"], email["recipient_names"], email["subject"],
-                     email["body"], attachments, email["is_html"], email["attachment_access_token"])
+        return Email(email["sender"], email["application"], email["template"], email["from_account"], email["to"],
+                     email["recipient_names"], email["subject"], email["body"], attachments, email["is_html"], email["attachment_access_token"],
+                     email["override_send_name"])
 
 
 class EmailManagerService:
@@ -309,29 +340,31 @@ class EmailManagerService:
 
     def reload_accounts(self):
         with self.reload_lock:
-            accounts = execute_supplied_statement(self.connection, QUERY__load_email_accounts, as_objects=True,
-                                                  decrypt_columns=[KEY__encrypted_password],
-                                                  encryption_key=self.db_crypt_key)
+            accounts = execute_supplied_statement(self.connection, QUERY__load_email_accounts, as_objects=True)
+            for account in accounts:
+                account[KEY__encrypted_password] = decrypt_raw(self.db_crypt_key, account[KEY__encrypted_password])
             email_queues = {}
 
             for account in accounts:
-                if account[KEY__email_account_name] not in self.email_credentials and account[KEY__encrypted_password] is None:
+                if account[KEY__email_account_name] not in self.email_credentials.credentials and account[KEY__encrypted_password] is None:
                     raise Exception(ERR__password_not_found % account[KEY__email_account_name])
-                elif account[KEY__email_account_name] in self.email_credentials and account[KEY__encrypted_password] is None:
+                elif account[KEY__email_account_name] in self.email_credentials.credentials and account[KEY__encrypted_password] is None:
                     execute_supplied_statement(self.connection, QUERY__update_email_account_password,  # Stores the password
-                                               {KEY__encrypted_password: self.email_credentials[account[KEY__email_account_name]],
+                                               {KEY__encrypted_password: self.email_credentials.credentials[account[KEY__email_account_name]],
                                                 KEY__id: account[KEY__id]},
-                                               encrypt_parameters=[KEY__encrypted_password])
+                                               encrypt_parameters=[KEY__encrypted_password],
+                                               encryption_key=self.db_crypt_key)
                 cur_queue = Queue()
-                if str(account[KEY__id]) not in self.email_queues:
-                    email_queues[str(account[KEY__id])] = cur_queue
+
+                if str(account[KEY__email_account_name]) not in self.email_queues:
+                    email_queues[str(account[KEY__email_account_name])] = cur_queue
                     password = account[KEY__encrypted_password]
                     if password is None:
                         password = self.email_credentials[account[KEY__email_account_name]]
                     method_args = [account, cur_queue, password]
                     threading.Thread(target=self.email_connection_thread, args=method_args, daemon=True).start()
                 else:
-                    email_queues[str(account[KEY__id])] = self.email_queues[str(account[KEY__id])]
+                    email_queues[str(account[KEY__email_account_name])] = self.email_queues[str(account[KEY__email_account_name])]
 
             self.email_queues = email_queues
 
@@ -348,7 +381,10 @@ class EmailManagerService:
         message_final = MIMEMultipart('mixed')
         message_final.attach(message)
         message_final[EMAIL__to] = SPLIT__address.join(email.to)
-        message_final[EMAIL__from] = account[KEY__email_account_send_name] + " <" + account[KEY__email_account_username] + ">"
+        send_name = account[KEY__email_account_send_name]
+        if email.override_send_name is not None:
+            send_name = email.override_send_name
+        message_final[EMAIL__from] = send_name + " <" + account[KEY__email_account_username] + ">"
         message_final[EMAIL__subject] = email.subject
 
         if email.attachments is not None:
@@ -361,7 +397,7 @@ class EmailManagerService:
     def is_connected(self, conn: smtplib.SMTP):
         try:
             status = conn.noop()[0]
-        except Exception as ex:
+        except Exception:
             status = -1
         return True if status == 250 else False
 
@@ -411,8 +447,10 @@ class EmailManagerService:
                     print(email.to)
 
                 execute_supplied_statement(self.connection, QUERY__ins_email_history, {
+                        KEY__application: email.application,
                         KEY__template: email.template,
                         KEY__sender: email.sender,
+                        KEY__override_send_name: email.override_send_name,
                         KEY__encrypted_subject: email.subject,
                         KEY__encrypted_body: formatted_body,
                         KEY__encrypted_attachments: self.format_attachments_for_storage(email.attachments),
@@ -427,23 +465,25 @@ class EmailManagerService:
                     ]
                 )
             except Empty:
-                if str(account[KEY__id]) not in self.email_queues:
+                if account[KEY__email_account_name] not in self.email_queues:
                     break
-            except:
+            except Exception:
                 traceback.print_exc()  # Something went wrong
 
         try:
             conn.quit()
-        except:
+        except Exception:
             pass
 
     def send_email(self, email: Email):
         if email.from_account in self.email_queues:
             self.email_queues[email.from_account].put(email)
         else:
-            print("Available email accounts:")
-            print(self.email_queues.keys())
-            raise Exception(ERR__email_not_found % email.from_account)
+            self.reload_accounts()
+            if email.from_account in self.email_queues:
+                self.email_queues[email.from_account].put(email)
+            else:
+                raise Exception(ERR__email_not_found % email.from_account)
 
 
 def create_app(ems: EmailManagerService):
