@@ -19,10 +19,6 @@ class JAAQLController(BaseJAAQLController):
         def fetch_oauth_token(http_inputs: dict, ip_address: str, response: JAAQLResponse):
             return self.model.get_auth_token(**http_inputs, ip_address=ip_address, response=response)
 
-        @self.cors_route('/internal/tenants', DOCUMENTATION__add_tenant)
-        def tenants(connection: DBInterface, http_inputs: dict):
-            self.model.add_tenant(connection, **http_inputs)
-
         @self.cors_route('/internal/redeploy', DOCUMENTATION__deploy)
         def redeploy(connection: DBInterface):
             return self.model.redeploy(connection)
@@ -31,9 +27,9 @@ class JAAQLController(BaseJAAQLController):
         def refresh_oauth_token(auth_token: str, ip_address: str):
             return self.model.refresh_auth_token(auth_token, ip_address)
 
-        @self.cors_route('/refresh-app-config', DOCUMENTATION__refresh_app_config)
-        def refresh_app_config(connection: DBInterface, tenant: str, inputs: dict):
-            self.model.refresh_cached_canned_query_service(connection, tenant, **inputs)
+        @self.cors_route('/internal/canned-queries', DOCUMENTATION__canned_queries)
+        def refresh_app_config(connection: DBInterface, inputs: dict):
+            self.model.refresh_cached_canned_query_service(connection, **inputs)
 
         @self.cors_route(ENDPOINT__install, DOCUMENTATION__install)
         def install(http_inputs: dict):
@@ -52,31 +48,24 @@ class JAAQLController(BaseJAAQLController):
             self.model.is_alive()
 
         @self.cors_route('/email/account', DOCUMENTATION__drop_email_account)
-        def drop_email_account(tenant: str, http_inputs: dict, connection: DBInterface):
-            self.model.drop_email_account(tenant, connection, **http_inputs)
+        def drop_email_account(http_inputs: dict, connection: DBInterface):
+            self.model.drop_email_account(connection, **http_inputs)
 
-        @self.cors_route('/database', DOCUMENTATION__databases)
-        def drop_database(tenant: str, http_inputs: dict, connection: DBInterface):
-            if self.is_delete():
-                self.model.drop_database(tenant, connection, **http_inputs)
-            else:
-                self.model.create_database(connection, **http_inputs)
-
-        @self.cors_route('/accounts', DOCUMENTATION__create_tenant_account)
-        def accounts(connection: DBInterface, tenant: str, http_inputs: dict):
-            self.model.create_tenant_account(connection, tenant, http_inputs)
+        @self.cors_route('/accounts', DOCUMENTATION__create_account)
+        def accounts(connection: DBInterface, http_inputs: dict):
+            self.model.create_account(connection, http_inputs)
 
         @self.cors_route('/account/password', DOCUMENTATION__password)
-        def password(user_id: str, username: str, tenant: str, ip_address: str, http_inputs: dict):
-            return self.model.add_my_account_password(user_id, username, tenant, ip_address, **http_inputs)
+        def password(user_id: str, username: str, ip_address: str, http_inputs: dict):
+            return self.model.add_my_account_password(user_id, username, ip_address, **http_inputs)
 
         @self.cors_route('/public', DOCUMENTATION__public_user)
         def public_user(http_inputs: dict):
             return self.model.fetch_public_user(**http_inputs)
 
         @self.cors_route('/submit', DOCUMENTATION__submit)
-        def submit(http_inputs: dict, user_id: str, tenant: str, verification_hook: queue.Queue):
-            return self.model.submit(http_inputs, user_id, tenant, verification_hook=verification_hook)
+        def submit(http_inputs: dict, user_id: str, verification_hook: queue.Queue):
+            return self.model.submit(http_inputs, user_id, verification_hook=verification_hook)
 
         @self.cors_route('/account/signup/request', DOCUMENTATION__sign_up_request_invite)
         def signup_request(http_inputs: dict):
@@ -91,12 +80,12 @@ class JAAQLController(BaseJAAQLController):
             return self.model.sign_up_user_with_token(http_inputs[KEY__invite_key], http_inputs[KEY__password])
 
         @self.cors_route('/account/signup/fetch', DOCUMENTATION__sign_up_fetch)
-        def signup_fetch(http_inputs: dict, tenant: str):
-            return self.model.fetch_signup(http_inputs[KEY__invite_key], tenant)
+        def signup_fetch(http_inputs: dict):
+            return self.model.fetch_signup(http_inputs[KEY__invite_key])
 
         @self.cors_route('/account/signup/finish', DOCUMENTATION__sign_up_finish)
-        def signup_finish(http_inputs: dict, tenant: str):
-            self.model.finish_signup(http_inputs[KEY__invite_key], tenant)
+        def signup_finish(http_inputs: dict):
+            self.model.finish_signup(http_inputs[KEY__invite_key])
 
         @self.cors_route('/account/reset-password', DOCUMENTATION__reset_password)
         def reset_password(http_inputs: dict):
@@ -111,18 +100,18 @@ class JAAQLController(BaseJAAQLController):
             return self.model.reset_password_perform_reset(http_inputs)
 
         @self.cors_route(ENDPOINT__jaaql_emails, DOCUMENTATION__email)
-        def emails(http_inputs: dict, tenant: str, auth_token: str, user_id: str, ip_address: str, is_public: bool, username: str):
+        def emails(http_inputs: dict, auth_token: str, user_id: str, ip_address: str, is_public: bool, username: str):
             if is_public:
                 raise HttpStatusException(ERR__user_public, HTTPStatus.UNAUTHORIZED)
 
-            return self.model.send_email(http_inputs, auth_token, user_id, tenant, ip_address, username)
+            return self.model.send_email(http_inputs, auth_token, user_id, ip_address, username)
 
         @self.cors_route('/documents', DOCUMENTATION__document)
-        def documents(http_inputs: dict, auth_token: str, ip_address: str, tenant: str, response: JAAQLResponse):
+        def documents(http_inputs: dict, auth_token: str, ip_address: str, response: JAAQLResponse):
             if self.is_get():
                 return self.model.fetch_document(http_inputs, response)
             else:
-                return self.model.render_document(http_inputs, auth_token, ip_address, tenant)
+                return self.model.render_document(http_inputs, auth_token, ip_address)
 
         @self.cors_route('/rendered_documents', DOCUMENTATION__rendered_document)
         def documents(http_inputs: dict):
